@@ -1,21 +1,11 @@
 '''
 Some simple tests to check that the framework is properly wrapped.
 '''
+from PyObjCTools.TestSupport import *
 import objc
-import unittest
 import InputMethodKit
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
-try:
-    long
-except NameError:
-    long = int
-
-class TestInputMethodKit (unittest.TestCase):
+class TestInputMethodKit (TestCase):
     def testClasses(self):
 
         self.assertTrue( hasattr(InputMethodKit, 'IMKInputController') )
@@ -45,4 +35,4 @@ class TestInputMethodKit (unittest.TestCase):
 
 
 if __name__ == "__main__":
-    unittest.main()
+    main()
